@@ -18,8 +18,18 @@ def create_ext(config):
         EXT_CONTEXT["db"] = _db
 
     if not EXT_CONTEXT.get("redis"):
-        _redis = create_redis(config)
-        EXT_CONTEXT["redis"] = _redis
+        _redis_configs = config.REDIS
+        if not _redis_configs:
+            return
+
+        ret_redis_config = dict()
+        for _redis_config in _redis_configs:
+            if _redis_config:
+                _redis = create_redis(_redis_configs[_redis_config])
+                if _redis:
+                    ret_redis_config[_redis_config] = _redis
+
+        EXT_CONTEXT["redis"] = ret_redis_config
 
     if not EXT_CONTEXT.get("es"):
         _es = create_es(config)
